@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: chasen.mli 71 2005-05-01 19:59:33Z yori $ *)
+(* $Id: chasen.mli 99 2005-07-03 18:47:47Z yori $ *)
 
 external romaji : string -> string = "caml_romaji"
 external katakana : string -> string = "caml_katakana"
@@ -69,3 +69,8 @@ val base : mrph_data -> string
 val info : mrph_data -> string
 val compound : mrph_data -> int
 val surface_form : mrph_data -> string
+
+val serialize_mrph : mrph -> string
+val deserialize_mrph : string -> mrph
+
+val new_word : kaki:string -> yomi:string -> mrph list
