@@ -53,7 +53,6 @@ let rec scm_candidates = function
 	   ScmTypes.datum_of_int l] in
       ScmTypes.cons x (scm_candidates path)
 
-
 let scm_list_candidates args =
   let string = ScmTypes.string_of_scm_string (ScmTypes.car args) in
   let state = ScmTypes.exact_int_of_datum (ScmTypes.cadr args) in
@@ -62,7 +61,12 @@ let scm_list_candidates args =
   let len = ScmTypes.exact_int_of_datum (ScmTypes.nth args 4) in
   scm_candidates 
     (Parse.list_candidates string ~state ~pos ~mrph_len ~len)
-       
+
+let scm_add_new_word args =
+  let kaki = ScmTypes.string_of_scm_string (ScmTypes.car args) in
+  let yomi = ScmTypes.string_of_scm_string (ScmTypes.cadr args) in
+  PersonalDict.add_new_word ~kaki ~yomi;
+  ScmTypes.Nil
 
 (* Some code comes from Schoca *)
 let _ =
@@ -74,9 +78,9 @@ let _ =
   let env = ScmEval.init_environment () in
   let env, _= ScmEval.register_scm_fun env "mana-best-path" scm_best_path in
   let env, _ = 
-    ScmEval.register_scm_fun env 
-      "mana-list-candidates" 
-      scm_list_candidates in
+    ScmEval.register_scm_fun env "mana-list-candidates" scm_list_candidates in
+  let env, _= 
+    ScmEval.register_scm_fun env "mana-add-new-word" scm_add_new_word in
   let rec exc_loop () =
     try ignore( ScmSchoca.parse_stream_with_environment env ~prompt lexbuf );
     with 
