@@ -13,14 +13,37 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
+let unescape s =
+  let b = Buffer.create 0 in
+  let p = ref 0 in
+  while !p < String.length s do
+    match s.[!p] with
+      '\\' ->
+	begin
+	  incr p;
+	  match s.[!p] with
+	    '0' .. '9' ->
+	      begin
+		let c = int_of_string (String.sub s !p 3) in
+		Buffer.add_char b (Char.chr c);
+		p := !p + 3;
+	      end
+	  | c -> 
+	      Buffer.add_char b  '\\'; Buffer.add_char b c;
+	      incr p;
+	end
+    | c -> Buffer.add_char b c; incr p
+  done;
+  Buffer.contents b
+	    
 let dic_lookup s p len = 
   PersonalDict.lookup s p len @
   Chasen.darts_lookup s p len
 
 let dic_lookup_prefix s p len =
   PersonalDict.lookup_prefix s p len @ 
-  Chasen.darts_lookup_prefix s p len
- 
+    Chasen.darts_lookup_prefix s p len
+
 let connect_mrph ~state ~mrph =
   let new_state, con_cost = 
     Chasen.connect_cost state mrph in
@@ -126,7 +149,7 @@ let add_vertex ~pos ~to_pos ~state mrph node_set =
       Hashtbl.remove node_set.(to_pos) new_state;
       Hashtbl.add node_set.(to_pos) new_state to_node
 
-let list_next_mrph string ~pos ~len =
+let list_next_mrph string ~pos ~len = 
   dic_lookup_prefix string pos len
 
 let parse string ~state ~pos ~len =
